@@ -4,6 +4,7 @@ from dataclasses import dataclass, asdict, field
 
 log = logging.getLogger(__name__)
 
+
 @dataclass
 class Card:
     technologyType: int = 0
@@ -49,6 +50,27 @@ class Card:
 
         return c
 
+
+@dataclass
+class Area:
+    uid: str = ""
+    name: str = ""
+
+    def __init__(self, area_dict: dict):
+        for property_name in area_dict:
+            if isinstance(area_dict[property_name], str):
+                setattr(self, property_name, area_dict[property_name])
+
+            if isinstance(area_dict[property_name], type(None)):
+                setattr(self, property_name, None)
+
+            if isinstance(area_dict[property_name], bool):
+                setattr(self, property_name, bool(area_dict[property_name]))
+
+    def dict(self):
+        return {k: str(v) for k, v in asdict(self).items()}
+
+
 @dataclass
 class SecurityGroup:
     ownerSiteUID: str = ""
@@ -122,6 +144,7 @@ class Cardholder:
     cardholderType: CardholderType
     securityGroup: SecurityGroup
     cardholderPersonalDetail: CardholderPersonalDetail
+    insideArea: Area
     ownerSiteUID: any
     securityGroupApiKey: any
     ownerSiteApiKey: any
@@ -165,6 +188,8 @@ class Cardholder:
                         setattr(self, inner_property, cardholder_dict[property_name][0][inner_property])'''
 
             if isinstance(cardholder_dict[property_name], dict):
+                if property_name == "insideArea":
+                    self.insideArea = Area(cardholder_dict[property_name])
                 if property_name == "securityGroup":
                     self.securityGroup = SecurityGroup(cardholder_dict[property_name])
                 if property_name == "cardholderType":
@@ -236,6 +261,7 @@ class Cardholder:
 
         return ch
 
+
 if __name__ == "__main__":
     cardholdertype = CardholderType(typeName="test")
     print(cardholdertype.typeName)
@@ -243,4 +269,4 @@ if __name__ == "__main__":
     '''securityGroup = SecurityGroup(ownerSiteUID="1234",
                                   uid="sdfs", name="test", apiKey="None", description="test", isAppliedToVisitor=False)
     print(securityGroup.name)
-    print(securityGroup.uid)'''
\ No newline at end of file
+    print(securityGroup.uid)'''
